#!/bin/bash
# -*- coding: utf-8 -*-

# 作成：2020/10/09：榎本 啓希（ENOMOTO Yoshiki）
# 修正：2020/10/11：青木 淳（AOKI Atsushi）
# 修正：2020/10/14：青木 淳（AOKI Atsushi）
# 修正：2021/02/10：青木 淳（AOKI Atsushi）

: << EOF_COMMENT
-----------------------------------------------------------
【b2a：bluetree to aokilab】

このシェルスクリプト「b2a.sh」は、コマンドラインに含まれる文字列「http://bluetree.kyoto-su.ac.jp」を、
文字列「http://aokilab.kyoto-su.ac.jp」に置き換えた新たなコマンドラインを作成して、それを実行します。

オンライン授業のために、学内のみの「bluetree」を、学外からもアクセスできる「aokilab」に置換するのに便利でしょう。
ちなみに、このファイル名「b2a.sh」は「bluetree」を「aokilab」にする「b to a」ということを意図して名付けました。

準備：ホームディレクトリ「${HOME}」の直下に「bin」を用意して、そこに「b2a.sh」を移し、拡張属性を落とし、実行権を与えておきます。
  $ mkdir -p ~/bin ; mv ./b2a.sh ~/bin/ ; xattr -c ~/bin/b2a.sh ; chmod +x ~/bin/b2a.sh
典型的な使い方：実行したいコマンドラインの前に「~/bin/b2a.sh」を置くだけになります。
  $ ~/bin/b2a.sh svn checkout --username student http://bluetree.kyoto-su.ac.jp/repositories/AP/Java/ApacheAnt/Example/
  $ ~/bin/b2a.sh svn checkout --username student http://bluetree.kyoto-su.ac.jp/repositories/AP/Java/ApacheAnt/Example{A,B,C,D,E,F}/

エリアス（alias：別名を付ける）を使えば、さらに簡潔になります。（エリアス指定は「~/.bash_profile」などに記したほうがマッチベター。）
  $ alias b2a='sh ~/bin/b2a.sh'
  $ b2a svn checkout --username student http://bluetree.kyoto-su.ac.jp/repositories/AP/Java/ApacheAnt/Example{,A,B,C,D,E,F}/

-----------------------------------------------------------
EOF_COMMENT

SEARCH_STRING='bluetree.kyoto-su.ac.jp'
REPLACE_STRING='aokilab.kyoto-su.ac.jp'

OLD_COMMAND_LINE=${@}
NEW_COMMAND_LINE=''
NUMBER_OF_ARGUMENTS=${#}
ARGUMENT_COUNTER='1'
for EACH_ARGUMENT in ${OLD_COMMAND_LINE}
do
    echo ${EACH_ARGUMENT} | grep -E 'http[s]?://'${SEARCH_STRING} > /dev/null 2>&1
    if [ ${?} = 0 ]
    then NEW_COMMAND_LINE+="${EACH_ARGUMENT/${SEARCH_STRING}/${REPLACE_STRING}}"
    else NEW_COMMAND_LINE+="${EACH_ARGUMENT}"
    fi
    if [ ${ARGUMENT_COUNTER} -lt ${NUMBER_OF_ARGUMENTS} ]
    then NEW_COMMAND_LINE+=" "
    fi
    ARGUMENT_COUNTER=`expr ${ARGUMENT_COUNTER} + 1`
done

echo '+ '${NEW_COMMAND_LINE}
eval "${NEW_COMMAND_LINE}"

exit 0
